@@ -1,10 +1,13 @@
 #!/usr/local/bin/perl -w
 
+use lib '../.';
+
 use strict;
 use Carp;
 use Tk;
 use Tk::Graph;
 use Tk::BrowseEntry;
+use Tk::NumEntry;
 
 use DBI;
 use Data::Dumper;
@@ -34,11 +37,11 @@ my $cc = $fc->Graph(
 	-titlecolor	=> 'Brown',
 	-yformat	=> '%2.2f',
 
-	-ylabel		=> 'cpu',
-	-xlabel		=> 'seconds',
+#	-ylabel		=> 'cpu',
+#	-xlabel		=> 'seconds',
 
         -barwidth 	=> 15,
-	-padding	=> [20,20,20,50],	# Padding [top, right, buttom, left]
+	-padding	=> [20,20,20,100],	# Padding [top, right, buttom, left]
 	-linewidth	=> 1,
 	-shadow		=> 'gray50',
 	-shadowdepth	=> 3,
@@ -48,33 +51,51 @@ my $cc = $fc->Graph(
 	-legend		=> 1,
 	)->pack(-expand => 1, -fill => 'both');
 
+
+# Button Frame
+my $fra = $mw->Frame();
+
 # Typ
-my $opt = $mw->BrowseEntry(
-	-options  	=> ['HBARS', 'Circle', 'Bars', 'Line'],
+my $opt = $fra->BrowseEntry(
+	-options  	=> ['BARS', 'HBARS', 'CIRCLE', 'LINE'],
 	-variable 	=> \$typ,
 	-command  	=> sub { 
 			$cc->configure(-type => uc($typ));
 			$cc->redraw();
 		},
-	);
+	)->pack(-side => 'left');
 
 # Field
 my @fields = $t->fields;
 @fields = sort grep(! /^$/, @fields);
 
-my $fie = $mw->BrowseEntry(
+my $fie = $fra->BrowseEntry(
 	-options  	=> \@fields,
 	-variable 	=> \$field,
 	-command  	=> sub { 
 			$cc->configure(-ylabel => $field);
 			$cc->clear();
 		},
-	);
+	)->pack(-side => 'left');
+
+my $threed = 0;
+my $thr = $fra->NumEntry(
+	-textvariable 	=> \$threed,
+	-minvalue	=> 0,
+	-maxvalue	=> 50,
+	)->pack(-side => 'left');
+
+my $gbu = $fra->Button(
+	-text 		=> '3D', 
+	-command 	=> sub { 
+				$cc->configure(-threed => $threed);
+				$cc->redraw;
+			},
+	)->pack(-side => 'left');
 
 # Packs
-$fc->pack(-expand => 1, -fill => 'both', -anchor => 'nw', -side => 'top');
-$opt->pack();
-$fie->pack();
+$fc ->pack(-expand => 1, -fill => 'both', -anchor => 'nw', -side => 'top');
+$fra->pack(-expand => 1, -fill => 'both', -anchor => 'nw', -side => 'top');
 
 
 
@@ -109,4 +130,4 @@ sub refresh {
 	$widget->set(\%data);
 }
 
-         
\ No newline at end of file
+         
